@@ -17,7 +17,7 @@ use vars qw($VERSION);
 use Carp;
 use Symbol;
 
-$VERSION = "4.3";
+$VERSION = "4.4";
 
 my $Dummy = '[Error: stale reference!]';  ##  Dummy class name
 
@@ -235,15 +235,19 @@ sub _read_item_
         {
             $item = ${*{$where}}[$index];
             ${$entry}[0]++;
-            if (ref($item))
+            if (defined $item)
             {
-                if (ref($item) eq $Class)
+                if (ref($item))
                 {
-                    unshift(@{$stack}, [ 0, $item ]);
+                    if (ref($item) eq $Class)
+                    {
+                        unshift(@{$stack}, [ 0, $item ]);
+                    }
+                    return &_read_item_($location);
                 }
-                return &_read_item_($location);
+                else { return $item; }
             }
-            else { return $item; }
+            else { return ""; }
         }
         else
         {
@@ -260,7 +264,7 @@ sub _read_list_
     my(@result);
     my($item);
 
-    while ($item = &_read_item_($location))
+    while (defined ($item = &_read_item_($location)))
     {
         push(@result, $item);
     }
@@ -2019,7 +2023,7 @@ perltoot(1), perltie(1), printf(3), sprintf(3).
 
 =head1 VERSION
 
-This man page documents "Data::Locations" version 4.3.
+This man page documents "Data::Locations" version 4.4.
 
 =head1 AUTHOR
 
